<div align="center">
  <img src="https://i.imgur.com/vUEEcII.png"><br>
</div>


---------
# Sun Tzu: The Art of Data Science
---------
| | |
| --- | --- |
| Package | [![PyPI Latest Release](https://img.shields.io/pypi/v/suntzu.svg)](https://pypi.python.org/pypi/suntzu) <!-- ([![PyPI Downloads](https://img.shields.io/pypi/dm/pandas.svg?label=PyPI%20downloads)](https://pypi.org/project/pandas/) [![Conda Latest Release](https://anaconda.org/conda-forge/pandas/badges/version.svg)](https://anaconda.org/conda-forge/pandas) [![Conda Downloads](https://img.shields.io/conda/dn/conda-forge/pandas.svg?label=Conda%20downloads)](https://anaconda.org/conda-forge/pandas)) -->|
| Docs | [![Docs](https://readthedocs.org/projects/suntzu/badge/?version=latest)](https://suntzu.readthedocs.io/en/latest/?version=latest)|


## What is it?


Library Fusion in Python for Data Analysis: Streamlining data analysis workflows by combining and enhancing Python libraries.

## How to to install it?


## License
[MIT](LICENSE)

## Main Features
* TODO

# Credits

 - This package was created with [Cookiecutter](https://github.com/audreyr/cookiecutter) and the [`audreyr/cookiecutter-pypackage`](https://github.com/audreyr/cookiecutter-pypackage) project template.
